#! /bin/sh
## File:        runCxx.sh
## Package:     Babel cca hello examples
## Copyright:   (c) 2000-2001 The Regents of the University of California
## Revision:    $Revision: 4434 $
## Modified:    $Date: 2005-03-17 09:05:29 -0800 (Thu, 17 Mar 2005) $
## Description: script to run F77 dynamically loading CCA hello implementations
##

SIDL_DLL_PATH="libDriver.scl;../libdecaf/libdecaf.scl;../hello-server/libHelloServer.scl;../hello-client/libHelloClient.scl"
export SIDL_DLL_PATH

./HelloDriver

./HelloDriver2
